@@ -11,14 +11,21 @@ class Stack(NekoModule):
     """
     The module version of torch.stack function family.
 
+    Args:
+        mode (``str``, optional): The mode of the pytorch stack type. Default original stack.
+        dim (``int``, optional): The dimension of stack apply to. Cannot use in non-default mode. Default 0.
 
+    Examples::
+
+        dstack = Stack("d")
+        x_stack = dstack([x1, x2])
 
     """
 
     def __init__(self, mode: str = "", dim: int = 0):
         super().__init__()
         # other mode cannot specify the dim
-        assert not (mode == "" and dim != 0), "Other modes cannot specify the dim"
+        assert not (mode != "" and dim != 0), "Other modes cannot specify the dim"
         if mode == "":
             self.stack_func = F(torch.stack, dim=dim)
         elif mode.lower() == "d":
@@ -32,8 +39,7 @@ class Stack(NekoModule):
         elif mode.lower() == "row":
             self.stack_func = torch.row_stack
         else:
-            raise ValueError("""Not a valid `mode` argument. It should be in ["", "d", "v", "h", "column", "row"].
-            """)
+            raise ValueError("""Not a valid `mode` argument. It should be in ["", "d", "v", "h", "column", "row"].""")
 
     def forward(self, tensors: Union[List[Tensor], Tuple[Tensor, ...]]) -> Tensor:
         return self.stack_func(tensors)
