@@ -1,4 +1,4 @@
-from .imshow import imshow
+from .matplotlib import imshow
 from .log_graph import log_graph
 from . import watcher
 from . import tensorboard
