@@ -1,4 +1,4 @@
-from .component import Component, Variable, ProgressBar, Image
+from .component import Component, Variable, ProgressBar, Image, Logger
 from .view import View
 from .server import Server
 
@@ -7,6 +7,7 @@ __all__ = [
     "Variable",
     "ProgressBar",
     "Image",
+    "Logger",
     "View",
     "Server"
 ]
